@@ -8,7 +8,6 @@ describe 'basic swift' do
       pp= <<-EOS
       include openstack_integration
       include openstack_integration::repos
-      include openstack_integration::apache
       include openstack_integration::rabbitmq
       include openstack_integration::mysql
       include openstack_integration::keystone
@@ -132,7 +131,6 @@ describe 'basic swift' do
       swiftinit_pp= <<-EOS
       include openstack_integration
       include openstack_integration::repos
-      include openstack_integration::apache
       include openstack_integration::rabbitmq
       include openstack_integration::mysql
       include openstack_integration::keystone
@@ -235,7 +233,7 @@ describe 'basic swift' do
         service_provider   => 'swiftinit',
       }
       class { 'swift::proxy::authtoken':
-        admin_password => 'a_big_secret',
+        password => 'a_big_secret',
       }
       class { 'swift::keystone::dispersion': } -> class { 'swift::dispersion': }
       class {'::swift::objectexpirer':
